==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/ca/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Configuració del <strong>compte</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirmeu</strong> la vostra adreça electrònica nova',
    '<strong>Permissions</strong>' => '<strong>Permisos</strong>',
    '<strong>Your</strong> profile' => '<strong>El teu</strong> perfil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Afegiu etiquetes al vostre perfil que us descriguin i destaquin les vostres habilitats i interessos. Les teves etiquetes es mostraran al teu perfil i al directori \'Persones\'.',
    'All your personal data will be irrevocably deleted.' => 'Totes les teves dades personals seran suprimides de manera irrevocable.',
    'Are you sure that you want to delete your account?' => 'Esteu segur que voleu suprimir el vostre compte?',
    'Blocked users' => 'Usuaris bloquejats',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Canviar el nom d\'usuari pot fer que alguns enllaços no es puguin utilitzar, per exemple enllaços antics al perfil.',
    'Confirm' => 'Confirma',
    'Current password' => 'Contrasenya actual',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definiu la configuració bàsica del vostre perfil. Podeu afegir etiquetes que us convinguin, triar l\'idioma i la vostra zona horària i bloquejar usuaris maleducats.',
    'Delete account' => 'Elimina el compte',
    'Do you really want to delete your icon image?' => 'Realment voleu suprimir la vostra imatge d\'icona?',
    'Do you really want to delete your logo image?' => 'Realment voleu suprimir la imatge del vostre logotip?',
    'E-Mail' => 'Correu electrònic',
    'E-Mail change' => 'Modificació del correu electrònic',
    'Enter your password to continue' => 'Indica el teu password per continuar',
    'General' => 'General',
    'Hello' => 'Hola',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aquí podeu editar les dades generals del vostre perfil, que són visibles a la pàgina d\'informació del vostre perfil.',
    'Hide introduction tour panel on dashboard' => 'Amaga el tour introductori al Dashboard',
    'Invalid link! Please make sure that you entered the entire url.' => 'Enllaç invàlid! Si us plau, assegura\'t que has introduït la URL sencera.',
    'Language' => 'Llengua',
    'Modules' => 'Mòduls',
    'New E-Mail address' => 'Nou correu electrònic',
    'New User name' => 'Nou nom d\'usuari',
    'Not registered users' => 'Usuaris no registrats',
    'Notifications' => 'Avisos',
    'Other users' => 'Altres usuaris',
    'Password Recovery' => 'Recuperació de la contrasenya',
    'Permissions' => 'Permisos',
    'Profile' => 'Perfil',
    'Profile Tags' => 'Etiquetes del perfil',
    'Profile visibility' => 'Visibilitat del perfil',
    'Registered users only' => 'Només usuaris registrats',
    'Save' => 'Desa',
    'Save profile' => 'Desar perfil',
    'The entered e-mail address is already in use by another user.' => 'L\'e-mail introduïr ja està en ús per un altre usuari.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Aquesta configuració us permet determinar quins permisos voleu concedir als visitants del vostre perfil individual. Cada usuari pot ajustar lliurement la configuració del seu propi perfil.',
    'TimeZone' => 'TimeZone',
    'Username has been changed' => 'El nom d\'usuari ha estat canviat',
    'Users' => 'Usuaris',
    'Visible for all (also unregistered users)' => 'Visible per tothom (inclús usuaris no registrats)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabem d\'enviar un correu electrònic de confirmació a la teva nova adreça. <br /> Si us plau, segueix les instruccions.',
    'You are currently the owner of following spaces:' => 'Actualment ets el propietari dels següents espais:',
    'You cannot use this username.' => 'No pots utilitzar aquest nom d\'uasuari.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Heu sol·licitat canviar la vostra adreça de correu electrònic.<br>La vostra adreça de correu electrònic nova és {newemail}.<br><br>Per confirmar la vostra nova adreça de correu electrònic, feu clic al botó següent.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Heu canviat correctament el vostre nom d\'usuari.<br>El vostre nou nom d\'usuari és {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Heu de transferir la propietat o suprimir aquests espais abans de poder suprimir el vostre compte.',
    'Your account cannot be deleted!' => 'El teu compte no es pot eliminar!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'La teva adreça d\'e-mail actual és <b>{email}</b>. Pots canviar el teu e-mail actual aquí.',
    'Your current password can be changed here.' => 'El teu password actual es pot canviar aquí.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'El vostre nom d\'usuari actual és <b>{username}</b>. Podeu canviar el vostre nom d\'usuari actual aquí.',
    'Your e-mail address has been successfully changed to {email}.' => 'El nou correu electrònic associat és {email}.',
    'Your friends' => 'Els teus amics',
    'Your password has been successfully changed!' => 'La teva constrasenya s\'ha modificat correctament!',
    'Your username has been changed' => 'El teu nom d\'usuari ha estat canviat',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'El teu nom d\'usuari s\'ha canviat correctament. <br> T\'acabem d\'enviar un e-mail amb la nova informació.',
    '<strong>Your</strong> Account' => '',
    'Hide my online status' => '',
    'Markdown Editor Mode' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Rich Text' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/ca/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Configuració del <strong>compte</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirmeu</strong> la vostra adreça electrònica nova',
    '<strong>Permissions</strong>' => '<strong>Permisos</strong>',
    '<strong>Your</strong> profile' => '<strong>El teu</strong> perfil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Afegiu etiquetes al vostre perfil que us descriguin i destaquin les vostres habilitats i interessos. Les teves etiquetes es mostraran al teu perfil i al directori \'Persones\'.',
    'All your personal data will be irrevocably deleted.' => 'Totes les teves dades personals seran suprimides de manera irrevocable.',
    'Are you sure that you want to delete your account?' => 'Esteu segur que voleu suprimir el vostre compte?',
    'Blocked users' => 'Usuaris bloquejats',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Canviar el nom d\'usuari pot fer que alguns enllaços no es puguin utilitzar, per exemple enllaços antics al perfil.',
    'Confirm' => 'Confirma',
    'Current password' => 'Contrasenya actual',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definiu la configuració bàsica del vostre perfil. Podeu afegir etiquetes que us convinguin, triar l\'idioma i la vostra zona horària i bloquejar usuaris maleducats.',
    'Delete account' => 'Elimina el compte',
    'Do you really want to delete your icon image?' => 'Realment voleu suprimir la vostra imatge d\'icona?',
    'Do you really want to delete your logo image?' => 'Realment voleu suprimir la imatge del vostre logotip?',
    'E-Mail' => 'Correu electrònic',
    'E-Mail change' => 'Modificació del correu electrònic',
    'Enter your password to continue' => 'Indica el teu password per continuar',
    'General' => 'General',
    'Hello' => 'Hola',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aquí podeu editar les dades generals del vostre perfil, que són visibles a la pàgina d\'informació del vostre perfil.',
    'Hide introduction tour panel on dashboard' => 'Amaga el tour introductori al Dashboard',
    'Invalid link! Please make sure that you entered the entire url.' => 'Enllaç invàlid! Si us plau, assegura\'t que has introduït la URL sencera.',
    'Language' => 'Llengua',
    'Modules' => 'Mòduls',
    'New E-Mail address' => 'Nou correu electrònic',
    'New User name' => 'Nou nom d\'usuari',
    'Not registered users' => 'Usuaris no registrats',
    'Notifications' => 'Avisos',
    'Other users' => 'Altres usuaris',
    'Password Recovery' => 'Recuperació de la contrasenya',
    'Permissions' => 'Permisos',
    'Profile' => 'Perfil',
    'Profile Tags' => 'Etiquetes del perfil',
    'Profile visibility' => 'Visibilitat del perfil',
    'Registered users only' => 'Només usuaris registrats',
    'Save' => 'Desa',
    'Save profile' => 'Desar perfil',
    'The entered e-mail address is already in use by another user.' => 'L\'e-mail introduïr ja està en ús per un altre usuari.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Aquesta configuració us permet determinar quins permisos voleu concedir als visitants del vostre perfil individual. Cada usuari pot ajustar lliurement la configuració del seu propi perfil.',
    'TimeZone' => 'TimeZone',
    'Username has been changed' => 'El nom d\'usuari ha estat canviat',
    'Users' => 'Usuaris',
    'Visible for all (also unregistered users)' => 'Visible per tothom (inclús usuaris no registrats)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabem d\'enviar un correu electrònic de confirmació a la teva nova adreça. <br /> Si us plau, segueix les instruccions.',
    'You are currently the owner of following spaces:' => 'Actualment ets el propietari dels següents espais:',
    'You cannot use this username.' => 'No pots utilitzar aquest nom d\'uasuari.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Heu sol·licitat canviar la vostra adreça de correu electrònic.<br>La vostra adreça de correu electrònic nova és {newemail}.<br><br>Per confirmar la vostra nova adreça de correu electrònic, feu clic al botó següent.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Heu canviat correctament el vostre nom d\'usuari.<br>El vostre nou nom d\'usuari és {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Heu de transferir la propietat o suprimir aquests espais abans de poder suprimir el vostre compte.',
    'Your account cannot be deleted!' => 'El teu compte no es pot eliminar!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'La teva adreça d\'e-mail actual és <b>{email}</b>. Pots canviar el teu e-mail actual aquí.',
    'Your current password can be changed here.' => 'El teu password actual es pot canviar aquí.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'El vostre nom d\'usuari actual és <b>{username}</b>. Podeu canviar el vostre nom d\'usuari actual aquí.',
    'Your e-mail address has been successfully changed to {email}.' => 'El nou correu electrònic associat és {email}.',
    'Your friends' => 'Els teus amics',
    'Your password has been successfully changed!' => 'La teva constrasenya s\'ha modificat correctament!',
    'Your username has been changed' => 'El teu nom d\'usuari ha estat canviat',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'El teu nom d\'usuari s\'ha canviat correctament. <br> T\'acabem d\'enviar un e-mail amb la nova informació.',
    '<strong>Your</strong> Account' => '',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Hide my online status' => '',
    'Markdown Editor Mode' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Rich Text' => '',
];
